@@ -11,6 +11,12 @@ MEDIA_FILE_EXTENSIONS = [
     '.woff2', '.gif', '.ico', '.png', '.jpg', '.jpeg', '.svg', '.eot', '.tff', '.ttf', '.woff',
     '.webp', '.mp4', '.webm', '.mp3', '.pdf',
 ]
+
+SASS_SOURCE = 'sass'
+SASS_DESTINATION = 'assets'
+SASS_DESTINATION_GLOB_PATTERN = f'{SASS_DESTINATION}/**/*.css'
+SASS_OUTPUT_STYLES = ['nested', 'expanded', 'compact', 'compressed']
+
 GLOB_PATTERN = [
     "assets/**/*.html",
     "assets/**/*.json",
@@ -40,6 +46,8 @@ GLOB_PATTERN = [
     "partials/**/*.html",
     "templates/**/*.html",
     "locales/**/*.json",
+
+    f"{SASS_SOURCE}/**/*.scss",
 ]
 
 
@@ -47,6 +55,7 @@ class Config(object):
     apikey = None
     store = None
     theme_id = None
+    sass_output_style = None
 
     env = 'development'
 
@@ -71,6 +80,9 @@ class Config(object):
         if getattr(parser, 'store', None):
             self.store = parser.store
 
+        if getattr(parser, 'sass_output_style', None):
+            self.sass_output_style = parser.sass_output_style
+
         self.save(write_file)
 
     def validate_config(self):
@@ -86,6 +98,11 @@ class Config(object):
             pluralize = 'is' if len(error_msgs) == 1 else 'are'
             raise TypeError(f'[{self.env}] argument {message} {pluralize} required.')
 
+        if self.sass_output_style not in SASS_OUTPUT_STYLES:
+            raise TypeError(
+                f'[{self.env}] argument -sos/--sass_output_style is unsupported '
+                'output_style; choose one of nested, expanded, compact, and compressed')
+
         return True
 
     def read_config(self, update=True):
@@ -94,11 +111,14 @@ class Config(object):
             with open(CONFIG_FILE, "r") as yamlfile:
                 configs = yaml.load(yamlfile, Loader=yaml.FullLoader)
                 yamlfile.close()
-
             if configs and configs.get(self.env) and update:
                 self.apikey = configs[self.env].get('apikey')
                 self.store = configs[self.env].get('store')
                 self.theme_id = configs[self.env].get('theme_id')
+
+                if configs[self.env].get('sass'):
+                    self.sass_output_style = configs[self.env]['sass'].get('output_style')
+
         return configs
 
     def write_config(self):
@@ -107,7 +127,10 @@ class Config(object):
         new_config = {
             'apikey': self.apikey,
             'store': self.store,
-            'theme_id': self.theme_id
+            'theme_id': self.theme_id,
+            'sass': {
+                'output_style': self.sass_output_style
+            }
         }
         # If the config has been changed, then the config will be saved to config.yml.
         if configs.get(self.env) != new_config:
